@@ -442,10 +442,14 @@ class Analyser(object):
                             match_dict[pattern.name]["sum"] += match
                         else:
                             match_dict[pattern.name]["sum"] = match
-                        if "sum2" in match_dict[pattern.name]:
-                            match_dict[pattern.name]["sum2"] += match ** 2
-                        else:
-                            match_dict[pattern.name]["sum2"] = match ** 2
+                        try:
+                            if "sum2" in match_dict[pattern.name]:
+                                match_dict[pattern.name]["sum2"] += match ** 2
+                            else:
+                                match_dict[pattern.name]["sum2"] = match ** 2
+                        except OverflowError:
+                            LOGGER.warning("Squared sum cannot be represented, numerical result out of range.")
+                            match_dict[pattern.name]["sum2"] = math.nan
 
                     if "cnt" in match_dict[pattern.name]:
                         match_dict[pattern.name]["cnt"] += 1
@@ -459,11 +463,14 @@ class Analyser(object):
                              match_dict[pattern.name]["cnt"])
 
                     if match_dict[pattern.name]["cnt"] > 1:
-                        match_dict[pattern.name]["std"] = math.sqrt(
-                            (abs(match_dict[pattern.name]["sum2"] -
-                                 (match_dict[pattern.name]["sum"] ** 2 /
-                                  match_dict[pattern.name]["cnt"])) /
-                             (match_dict[pattern.name]["cnt"] - 1)))
+                        try:
+                            match_dict[pattern.name]["std"] = math.sqrt(
+                                      (abs(match_dict[pattern.name]["sum2"] - 
+                                      (match_dict[pattern.name]["sum"] ** 2 /
+                                      match_dict[pattern.name]["cnt"])) /
+                                      (match_dict[pattern.name]["cnt"] - 1)))
+                        except OverflowError:
+                            match_dict[pattern.name]["std"] = 0
                     else:
                         match_dict[pattern.name]["std"] = 0
 
@@ -495,6 +502,8 @@ class Analyser(object):
         stepname -> workpackage_id -> filename -> patternname -> value
         """
         etree = list()
+        if self._analyse_result is None:
+            return etree
         for stepname in self._analyse_result:
             step_etree = ET.Element("step")
             step_etree.attrib["name"] = stepname
