@@ -1,5 +1,5 @@
 # JUBE Benchmarking Environment
-# Copyright (C) 2008-2019
+# Copyright (C) 2008-2021
 # Forschungszentrum Juelich GmbH, Juelich Supercomputing Centre
 # http://www.fz-juelich.de/jsc/jube
 #
@@ -97,10 +97,18 @@ def analyse_benchmarks(args):
 
 
 def remove_benchmarks(args):
-    """Remove benchmarks"""
-    found_benchmarks = search_for_benchmarks(args)
-    for benchmark_folder in found_benchmarks:
-        _remove_benchmark(benchmark_folder, args)
+    """Remove benchmarks or workpackages"""
+    if(args.workpackage is not None):
+        # If a workpackage id is provided by the user, only specific
+        # workpackages will be removed
+        found_workpackages = search_for_workpackage(args)
+        for workpackage in found_workpackages:
+            _remove_workpackage(workpackage, args)
+    else:
+        # Delete complete benchmarks
+        found_benchmarks = search_for_benchmarks(args)
+        for benchmark_folder in found_benchmarks:
+            _remove_benchmark(benchmark_folder, args)
 
 
 def command_help(args):
@@ -229,7 +237,7 @@ def _load_existing_benchmark(args, benchmark_folder, restore_workpackages=True,
 
     # Read existing benchmark configuration
     try:
-        parser = jube2.jubeio.XMLParser(os.path.join(
+        parser = jube2.jubeio.Parser(os.path.join(
             benchmark_folder, jube2.conf.CONFIGURATION_FILENAME),
             force=args.force, strict=args.strict)
         benchmarks = parser.benchmarks_from_xml()[0]
@@ -250,7 +258,7 @@ def _load_existing_benchmark(args, benchmark_folder, restore_workpackages=True,
     if restore_workpackages:
         # Read existing workpackage information
         try:
-            parser = jube2.jubeio.XMLParser(os.path.join(
+            parser = jube2.jubeio.Parser(os.path.join(
                 benchmark_folder, jube2.conf.WORKPACKAGES_FILENAME),
                 force=args.force, strict=args.strict)
             workpackages, work_stat = parser.workpackages_from_xml(benchmark)
@@ -262,7 +270,7 @@ def _load_existing_benchmark(args, benchmark_folder, restore_workpackages=True,
     if load_analyse and os.path.isfile(os.path.join(
             benchmark_folder, jube2.conf.ANALYSE_FILENAME)):
         # Read existing analyse data
-        parser = jube2.jubeio.XMLParser(os.path.join(
+        parser = jube2.jubeio.Parser(os.path.join(
             benchmark_folder, jube2.conf.ANALYSE_FILENAME),
             force=args.force, strict=args.strict)
         analyse_result = parser.analyse_result_from_xml()
@@ -337,6 +345,26 @@ def search_for_benchmarks(args):
     return found_benchmarks
 
 
+def search_for_workpackage(args):
+    """Search for existing workpackages"""
+    found_benchmarks = search_for_benchmarks(args)
+    found_workpackages = list()
+    for benchmark_folder in found_benchmarks:
+        benchmark = \
+            _load_existing_benchmark(args, benchmark_folder,
+                                     load_analyse=False)
+        if benchmark is not None:
+            for wp_id in args.workpackage:
+                if benchmark.workpackage_by_id(int(wp_id)) is None:
+                    raise RuntimeError(("No workpackage \"{0}\" found " +
+                                        "in benchmark \"{1}\".")
+                                       .format(wp_id, benchmark.id))
+                else:
+                    found_workpackages.append(
+                        benchmark.workpackage_by_id(int(wp_id)))
+    return found_workpackages
+
+
 def run_new_benchmark(args):
     """Start a new benchmark run"""
 
@@ -367,8 +395,8 @@ def run_new_benchmark(args):
                               args.include_path if include_path != ""]
         else:
             include_pathes = None
-        parser = jube2.jubeio.XMLParser(path, tags, include_pathes, args.force,
-                                        args.strict)
+        parser = jube2.jubeio.Parser(path, tags, include_pathes,
+                                     args.force, args.strict)
         benchmarks, only_bench, not_bench = parser.benchmarks_from_xml()
 
         # Add new comment
@@ -544,8 +572,8 @@ def _update_analyse_and_result(args, benchmark):
                               args.include_path if include_path != ""]
         else:
             include_pathes = None
-        parser = jube2.jubeio.XMLParser(args.update, tags, include_pathes,
-                                        args.force, args.strict)
+        parser = jube2.jubeio.Parser(args.update, tags, include_pathes,
+                                     args.force, args.strict)
         benchmarks = parser.benchmarks_from_xml()[0]
 
         # Update benchmark
@@ -578,6 +606,28 @@ def _remove_benchmark(benchmark_folder, args):
         shutil.rmtree(benchmark_folder, ignore_errors=True)
 
 
+def _remove_workpackage(workpackage, args):
+    """Remove existing workpackages"""
+    remove = True
+    # Ignore deleted/unstarted workpackages
+    if workpackage.started:
+        if not args.force:
+            try:
+                inp = raw_input(("Really remove \"{0}\" and its dependent " +
+                                 "workpackages (y/n):")
+                                .format(workpackage.workpackage_dir))
+            except NameError:
+                inp = input(("Really remove \"{0}\" and its dependent " +
+                             "workpackages (y/n):")
+                            .format(workpackage.workpackage_dir))
+            remove = inp.startswith("y")
+        if remove:
+            workpackage.remove()
+            workpackage.benchmark.write_workpackage_information(
+                os.path.join(workpackage.benchmark.bench_dir,
+                             jube2.conf.WORKPACKAGES_FILENAME))
+
+
 def _manipulate_comment(benchmark_folder, args):
     """Change or append the comment in given benchmark."""
     benchmark = _load_existing_benchmark(args,
@@ -740,7 +790,7 @@ def gen_subparser_conf():
                 {"type": int, "help": "show only last N benchmarks"},
             ("-s", "--style"):
                 {"help": "overwrites table style type",
-                 "choices": ["pretty", "csv"]}
+                 "choices": ["pretty", "csv", "aligned"]}
         }
     }
 
@@ -802,14 +852,17 @@ def gen_subparser_conf():
 
     # remove subparser
     subparser_configuration["remove"] = {
-        "help": "remove benchmark",
+        "help": "remove benchmark or workpackages",
         "func": remove_benchmarks,
         "arguments": {
             ('dir',):
                 {"metavar": "DIRECTORY", "nargs": "?",
                  "help": "benchmark directory", "default": "."},
             ("-i", "--id"):
-                {"help": "use benchmarks given by id",
+                {"help": "remove benchmarks given by id",
+                 "nargs": "+"},
+            ("-w", "--workpackage"):
+                {"help": "specifc workpackage id to be removed",
                  "nargs": "+"},
             ("-f", "--force"):
                 {"help": "force removing, never prompt",
