@@ -162,29 +162,22 @@ class Parameterset(object):
                       update_mode=NEVER_MODE):
         """Two Parametersets are compatible, if the intersection only contains
         equivilant parameters"""
-        # Find parameternames which exists in both parametersets
-        intersection = set(self.all_parameter_names) & \
-            set(parameterset.all_parameter_names)
-        for name in intersection:
-            if (not (self[name].update_allowed(update_mode) or
-                     parameterset[name].update_allowed(
-                         NEVER_MODE if (update_mode == USE_MODE) else
-                         update_mode)) and
-                    not self[name].is_equivalent(parameterset[name])):
-                return False
-        return True
+        return len(self.get_incompatible_parameter(parameterset,update_mode)) == 0
 
     def get_incompatible_parameter(self, parameterset,
                                    update_mode=NEVER_MODE):
         """Return a set of incompatible parameter names between the current
         and the given parameterset"""
         result = set()
+        # Find parameternames which exists in both parametersets
         intersection = set(self.all_parameter_names) & \
             set(parameterset.all_parameter_names)
         for name in intersection:
             if (not (self[name].update_allowed(update_mode) or
+                     # In case of the USE_MODE (in the beginning of a new step) only the actual
+                     # new parameterset and its mode is relevant
                      parameterset[name].update_allowed(
-                         STEP_MODE if (update_mode == USE_MODE) else
+                         NEVER_MODE if (update_mode == USE_MODE) else
                          update_mode)) and
                     not self[name].is_equivalent(parameterset[name])):
                 result.add(name)
